# Generated by Django 3.1.2 on 2020-10-19 14:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cast", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="blog",
            name="description",
        ),
    ]
